# -*- coding: utf-8 -*-

from __future__ import unicode_literals

__name__ = 'django_agilesites'
__author__ = 'Steven Klass'
__version_info__ = (1, 0, 1)
__version__ = '.'.join(map(str, __version_info__))
__date__ = '2014/07/22 4:47:00 PM'
__credits__ = ['Steven Klass', 'Tim Valenta']
__license__ = 'See the file LICENSE.txt for licensing information.'
